﻿#region Header

// Copyright (c) Dundas Data Visualization Inc. All rights reserved.
//
// THIS SOURCE CODE IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT WITHOUT ANY
// WARRANTY. IT IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED
// OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE
// QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE
// DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
//
// IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW THE AUTHOR WILL BE LIABLE TO YOU
// FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES
// ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT
// LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY
// YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
// PROGRAMS), EVEN IF THE AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
// DAMAGES.

#endregion Header

using Dundas.BI;
using Dundas.BI.Configuration;
using Dundas.BI.Extensibility;

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;

namespace MyCompany.Sample.AppConfigSample
{
	/// <summary>
	/// This class contains the package information about the extension package.
	/// </summary>
	public class AppConfigSamplePackageInfo : ExtensionPackageInfo
	{
		#region Static Fields

		private static Guid HelloWorldPropertyId = new Guid("8a43fad9-c0da-4db7-ae13-589485e5051b");

		#endregion Static Fields

		#region Public Properties

		/// <summary>
		/// Gets the name of the extension package author.
		/// </summary>
		public override string Author
		{
			get { return "Dundas Data Visualization Sample Author"; }
		}

		/// <summary>
		/// Gets the copyright text associated with the extension package.
		/// </summary>
		public override string Copyright
		{
			get { return "Dundas Data Visualization, Inc."; }
		}

		/// <summary>
		/// Gets the localized display name of the extension package.
		/// </summary>
		public override string DisplayName
		{
			get {   return "App Config Sample Package";  }
		}

		/// <summary>
		/// Gets the unique identifier of the extension package.
		/// </summary>
		public override Guid Id
		{
			get { return new Guid("c1fdbe6b-bc39-4e95-bbf4-2fa77edaeabe"); }
		}

		/// <summary>
		/// Gets the name of the extension package.
		/// </summary>
		public override string Name
		{
			get { return "AppConfig Sample Package"; }
		}

		/// <summary>
		/// Gets the version of the extension package.
		/// </summary>
		public override Version Version
		{
			get { return new Version(0, 0, 1); }
		}

		#endregion Public Properties

		#region Private Methods

		private void RegisterSettings()
		{
			IAppConfigService appConfigService =
				Engine.Current.GetService<IAppConfigService>();

			AppSettingProperties appSettingsProperties =
				new AppSettingProperties(
					AppConfigSamplePackageInfo.HelloWorldPropertyId,
					"HelloWorldProperty",
					this.Id,
					typeof(string)
			);
			appSettingsProperties.CategoryName = "Hello World Category";
			appSettingsProperties.Description = "Hello World Property";

			int maxLength = 1000;
			bool isEmptyStringValid = true;
			Regex regularExpressionToMatch = new Regex("Hello[\\s](.*?)", RegexOptions.IgnoreCase);

			AppSettingValidationRule appSettingValidationRule =
				new StringValidationRule(maxLength, regularExpressionToMatch, isEmptyStringValid);

			appSettingsProperties.ValidationRule = appSettingValidationRule;

			appSettingsProperties.DefaultValue = string.Empty;
			appConfigService.RegisterSetting(appSettingsProperties);
		}

		#endregion Private Methods

		#region Public Methods

		public override void OnLoaded()
		{
			RegisterSettings();
		}

		#endregion Public Methods
	}
}